Disposable class abstract

Implement this interface to participate in CubePod's disposal lifecycle.

When a CubeContainer is disposed, all registered instances that implement Disposable will have their dispose method called automatically in reverse registration order (LIFO).

class ApiService implements Disposable {
  @override
  void dispose() => _httpClient.close();
}
Implementers

Constructors

Disposable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited